@@ -232,6 +232,7 @@ class Go2RtcRTSPSource(TypedDict):
     opus: str
     pcma: str
     mp4: str
+    onvif: str
 
 
 class Go2RtcEndpoint(TypedDict):
@@ -983,13 +984,13 @@ class JsonSchemaArray(JsonBaseSchema[Any]):
 
 class JsonSchemaButton(JsonBaseSchema[Any]):
     type: Literal["button"]
-    color: NotRequired[str]
+    color: NotRequired[Literal["success", "info", "warn", "danger"]]
 
 
 class JsonSchemaObjectButton(TypedDict):
     label: str
     onSubmit: str
-    color: NotRequired[str]
+    color: NotRequired[Literal["success", "info", "warn", "danger"]]
 
 
 class JsonSchemaObjectWithButtons(JsonSchemaObject):
